@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2019-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,18 +44,9 @@ AccountListModel::AccountListModel(LRCInstance* instance, QObject* parent)
     // of computing the difference. The same goes for accounts being added and removed.
     // These operations will only occur when the list is hidden, unless dbus is used while
     // the list is visible.
-    QObject::connect(&lrcInstance_->accountModel(),
-                     &AccountModel::accountsReordered,
-                     this,
-                     &AccountListModel::reset);
-    QObject::connect(&lrcInstance_->accountModel(),
-                     &AccountModel::accountAdded,
-                     this,
-                     &AccountListModel::reset);
-    QObject::connect(&lrcInstance_->accountModel(),
-                     &AccountModel::accountRemoved,
-                     this,
-                     &AccountListModel::reset);
+    QObject::connect(&lrcInstance_->accountModel(), &AccountModel::accountsReordered, this, &AccountListModel::reset);
+    QObject::connect(&lrcInstance_->accountModel(), &AccountModel::accountAdded, this, &AccountListModel::reset);
+    QObject::connect(&lrcInstance_->accountModel(), &AccountModel::accountRemoved, this, &AccountListModel::reset);
 }
 
 int
