@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,7 +61,6 @@ extern const QString defaultDownloadPath;
     X(NeverShowMeAgain, false) \
     X(WindowGeometry, QRectF(qQNaN(), qQNaN(), 0., 0.)) \
     X(WindowState, QWindow::AutomaticVisibility) \
-    X(EnableExperimentalSwarm, false) \
     X(LANG, "SYSTEM") \
     X(SpellLang, {}) \
     X(EnableSpellCheck, true) \
@@ -86,7 +85,7 @@ extern const QString defaultDownloadPath;
 #define KEYS COMMON_KEYS \
     X(Donation2025StartDate, "2025-09-15 00:00") \
     X(IsDonationVisible, true) \
-    X(Donation2025EndDate, "2025-11-16 00:00")
+    X(Donation2025EndDate, "2026-01-01 00:00")
 #endif
 
 /*
@@ -156,6 +155,7 @@ public:
 Q_SIGNALS:
     void retranslate();
     void reloadHistory();
+    void localeChanged();
 
 private:
     QSettings* settings_;
