@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,7 @@ class AsyncAvatarImageResponseRunnable : public AsyncImageResponseRunnable
 {
     Q_OBJECT
 public:
-    AsyncAvatarImageResponseRunnable(const QString& id,
-                                     const QSize& requestedSize,
-                                     LRCInstance* lrcInstance)
+    AsyncAvatarImageResponseRunnable(const QString& id, const QSize& requestedSize, LRCInstance* lrcInstance)
         : AsyncImageResponseRunnable(id, requestedSize, lrcInstance)
     {}
 
