@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2021-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,14 +29,9 @@ AvatarRegistry::AvatarRegistry(LRCInstance* instance, QObject* parent)
             &AvatarRegistry::connectAccount,
             Qt::DirectConnection);
 
-    connect(&lrcInstance_->accountModel(),
-            &AccountModel::profileUpdated,
-            this,
-            &AvatarRegistry::addOrUpdateImage);
+    connect(&lrcInstance_->accountModel(), &AccountModel::profileUpdated, this, &AvatarRegistry::addOrUpdateImage);
 
-    connect(lrcInstance_, &LRCInstance::base64SwarmAvatarChanged, this, [&] {
-        addOrUpdateImage("temp");
-    });
+    connect(lrcInstance_, &LRCInstance::base64SwarmAvatarChanged, this, [&] { addOrUpdateImage("temp"); });
 
     if (!lrcInstance_->get_currentAccountId().isEmpty())
         connectAccount();
