@@ -1,13 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Anthony Léonard <anthony.leonard@savoirfairelinux.com>
- * Author: Olivier Soldano <olivier.soldano@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
- * Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
- * Author: Capucine Berthet <capucine.berthet@savoirfairelinux.com>
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,23 +54,17 @@ CallAdapter::CallAdapter(AppSettingsManager* settingsManager,
             this,
             &CallAdapter::onShowIncomingCallView);
 
-    connect(&lrcInstance_->behaviorController(),
-            &BehaviorController::showCallView,
-            this,
-            &CallAdapter::onShowCallView);
+    connect(&lrcInstance_->behaviorController(), &BehaviorController::showCallView, this, &CallAdapter::onShowCallView);
 
-    connect(lrcInstance_,
-            &LRCInstance::currentAccountIdChanged,
-            this,
-            &CallAdapter::onAccountChanged);
+    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, &CallAdapter::onAccountChanged);
 
 #ifdef Q_OS_LINUX
     // notification responses (gnu/linux currently)
     connect(systemTray_,
-            &SystemTray::answerCallActivated,
+            &SystemTray::acceptCallActivated,
             this,
             [this](const QString& accountId, const QString& convUid) {
-                acceptACall(accountId, convUid);
+                acceptCall(accountId, convUid);
                 Q_EMIT lrcInstance_->notificationClicked();
                 lrcInstance_->selectConversation(convUid, accountId);
                 updateCall(convUid, accountId);
@@ -87,9 +73,7 @@ CallAdapter::CallAdapter(AppSettingsManager* settingsManager,
     connect(systemTray_,
             &SystemTray::declineCallActivated,
             this,
-            [this](const QString& accountId, const QString& convUid) {
-                hangUpACall(accountId, convUid);
-            });
+            [this](const QString& accountId, const QString& convUid) { endCall(accountId, convUid); });
 #endif
 
     connect(&lrcInstance_->behaviorController(),
@@ -97,10 +81,7 @@ CallAdapter::CallAdapter(AppSettingsManager* settingsManager,
             this,
             QOverload<const QString&, const QString&>::of(&CallAdapter::onCallStatusChanged));
 
-    connect(lrcInstance_,
-            &LRCInstance::selectedConvUidChanged,
-            this,
-            &CallAdapter::saveConferenceSubcalls);
+    connect(lrcInstance_, &LRCInstance::selectedConvUidChanged, this, &CallAdapter::saveConferenceSubcalls);
 
 #ifdef HAVE_GLOBAL_PTT
     connectPtt();
@@ -124,9 +105,8 @@ CallAdapter::connectPtt()
             &PTTListener::pttKeyPressed,
             this,
             [this]() {
-                const auto callId
-                    = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(),
-                                                                accountId_);
+                const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(),
+                                                                              accountId_);
                 try {
                     isMicrophoneMuted_ = isMuted(callId);
                     if (isMicrophoneMuted_)
@@ -205,10 +185,7 @@ CallAdapter::onCallStatusChanged(const QString& accountId, const QString& callId
         if (systemTray_->hideNotification(QString("%1;%2").arg(accountId, convInfo.uid))
             && call.startTime.time_since_epoch().count() == 0) {
             // This was a missed call; show a missed call notification
-            auto convAvatar = Utils::conversationAvatar(lrcInstance_,
-                                                        convInfo.uid,
-                                                        QSize(50, 50),
-                                                        accountId);
+            auto convAvatar = Utils::conversationAvatar(lrcInstance_, convInfo.uid, QSize(50, 50), accountId);
             auto& accInfo = lrcInstance_->getAccountInfo(accountId);
             auto from = accInfo.conversationModel->title(convInfo.uid);
             auto notifId = QString("%1;%2").arg(accountId, convInfo.uid);
@@ -233,8 +210,7 @@ CallAdapter::onCallStarted(const QString& callId)
     auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId_);
     auto& callModel = accInfo.callModel;
     // update call Information list by adding the new information related to the callId
-    callInformationListModel_->addElement(
-        qMakePair(callId, callModel->advancedInformationForCallId(callId)));
+    callInformationListModel_->addElement(qMakePair(callId, callModel->advancedInformationForCallId(callId)));
     if (listener_->getPttState()) {
 #ifdef HAVE_GLOBAL_PTT
         listener_->startListening();
@@ -257,7 +233,7 @@ CallAdapter::onCallEnded(const QString& callId)
 }
 
 void
-CallAdapter::onCallStatusChanged(const QString& callId, int code)
+CallAdapter::onCallStatusChanged(const QString& accountId, const QString& callId, int code)
 {
     Q_UNUSED(code)
 
@@ -290,8 +266,7 @@ CallAdapter::onCallStatusChanged(const QString& callId, int code)
             const auto& currentConvInfo = lrcInstance_->getConversationFromConvUid(currentConvId);
 
             // was it a conference and now is a dialog?
-            if (currentConvInfo.isCoreDialog() && currentConvInfo.confId.isEmpty()
-                && currentConfSubcalls_.size() == 2) {
+            if (currentConvInfo.isCoreDialog() && currentConvInfo.confId.isEmpty() && currentConfSubcalls_.size() == 2) {
                 auto it = std::find_if(currentConfSubcalls_.cbegin(),
                                        currentConfSubcalls_.cend(),
                                        [&callId](const QString& cid) { return cid != callId; });
@@ -354,55 +329,62 @@ CallAdapter::onCallInfosChanged(const QString& accountId, const QString& callId)
 }
 
 void
-CallAdapter::onCallAddedToConference(const QString& callId, const QString& confId)
+CallAdapter::onCallAddedToConference(const QString& callId, const QString& conversationId, const QString& confId)
 {
     Q_UNUSED(callId)
     Q_UNUSED(confId)
+    Q_UNUSED(conversationId)
     saveConferenceSubcalls();
 }
 
 void
-CallAdapter::placeAudioOnlyCall()
+CallAdapter::onFallbackConversationSelected(const QString& accountId, const QString& conversationUid)
+{
+    qDebug() << "Fallback conversation selected, displaying conversation:" << conversationUid;
+    lrcInstance_->selectConversation(conversationUid, accountId);
+    Q_EMIT lrcInstance_->conversationUpdated(conversationUid, accountId);
+}
+
+void
+CallAdapter::startAudioOnlyCall()
 {
     const auto convUid = lrcInstance_->get_selectedConvUid();
     if (!convUid.isEmpty()) {
-        lrcInstance_->getCurrentConversationModel()->placeAudioOnlyCall(convUid);
+        lrcInstance_->getCurrentConversationModel()->startAudioOnlyCall(convUid);
     }
 }
 
 void
-CallAdapter::placeCall()
+CallAdapter::startCall()
 {
     const auto convUid = lrcInstance_->get_selectedConvUid();
     if (!convUid.isEmpty()) {
-        lrcInstance_->getCurrentConversationModel()->placeCall(convUid);
+        lrcInstance_->getCurrentConversationModel()->startCall(convUid);
     }
 }
 
 void
-CallAdapter::hangUpACall(const QString& accountId, const QString& convUid)
+CallAdapter::endCall(const QString& accountId, const QString& convUid)
 {
     const auto& convInfo = lrcInstance_->getConversationFromConvUid(convUid, accountId);
     if (!convInfo.uid.isEmpty()) {
-        lrcInstance_->getAccountInfo(accountId).callModel->hangUp(convInfo.callId);
+        auto callId = convInfo.confId.isEmpty() ? convInfo.callId : convInfo.confId;
+        lrcInstance_->getAccountInfo(accountId).callModel->end(callId);
     }
 }
 
 void
-CallAdapter::setCallMedia(const QString& accountId, const QString& convUid, bool video)
+CallAdapter::setCallMedia(const QString& accountId, const QString& convUid, bool videoMuted)
 {
     const auto& convInfo = lrcInstance_->getConversationFromConvUid(convUid, accountId);
     if (convInfo.uid.isEmpty())
         return;
-    try {
-        lrcInstance_->getAccountInfo(accountId).callModel->updateCallMediaList(convInfo.callId,
-                                                                               video);
-    } catch (...) {
-    }
+
+    lrcInstance_->getAccountInfo(accountId).callModel->setVideoMuted(convInfo.callId, videoMuted);
 }
 
 void
-CallAdapter::acceptACall(const QString& accountId, const QString& convUid)
+CallAdapter::acceptCall(const QString& accountId, const QString& convUid)
 {
     const auto& convInfo = lrcInstance_->getConversationFromConvUid(convUid, accountId);
     if (convInfo.uid.isEmpty())
@@ -446,8 +428,8 @@ CallAdapter::onShowIncomingCallView(const QString& accountId, const QString& con
     // - the call is incoming AND the call's target account is
     //   not a RendezVous point
     // - the call has just transitioned to the INCOMING_RINGING state
-    if (QApplication::focusObject() == nullptr && !call.isOutgoing
-        && !accountProperties.isRendezVous && call.status == call::Status::INCOMING_RINGING) {
+    if (QApplication::focusObject() == nullptr && !call.isOutgoing && !accountProperties.isRendezVous
+        && call.status == call::Status::INCOMING_RINGING) {
         // if the window is not focused then select the conversation immediately to show the call view
         if (isCallSelected) {
             Q_EMIT lrcInstance_->conversationUpdated(convInfo.uid, accountId);
@@ -472,23 +454,25 @@ CallAdapter::onShowIncomingCallView(const QString& accountId, const QString& con
     auto currentConvHasCall = accInfo.callModel->hasCall(currentConvInfo.callId);
     if (currentConvHasCall) {
         auto currentCall = accInfo.callModel->getCall(currentConvInfo.callId);
-        if ((currentCall.status == call::Status::CONNECTED
-             || currentCall.status == call::Status::IN_PROGRESS)
+        if ((currentCall.status == call::Status::CONNECTED || currentCall.status == call::Status::IN_PROGRESS)
             && !accountProperties.autoAnswer && !currentCall.isOutgoing) {
             showNotification(accountId, convInfo.uid);
             return;
         }
+        if (!accountProperties.denySecondCall) {
+            lrcInstance_->selectConversation(convInfo.uid, accountId);
+        }
+    } else {
+        // finally, in this case, the conversation isn't selected yet
+        // and there are no other special conditions, so just select the conversation
+        lrcInstance_->selectConversation(convInfo.uid, accountId);
     }
-
-    // finally, in this case, the conversation isn't selected yet
-    // and there are no other special conditions, so just select the conversation
-    lrcInstance_->selectConversation(convInfo.uid, accountId);
 }
 
 void
 CallAdapter::onShowCallView(const QString& accountId, const QString& convUid)
 {
-    Q_EMIT lrcInstance_->conversationUpdated(convUid, accountId); // This will show the call
+    Q_EMIT lrcInstance_->conversationUpdated(convUid, accountId);
 }
 
 void
@@ -511,8 +495,7 @@ CallAdapter::updateCall(const QString& convUid, const QString& accountId, bool f
         if (accInfo.profileInfo.type != lrc::api::profile::Type::SIP) {
             // Only setCurrentCall if call is actually answered
             try {
-                if (call->status == call::Status::IN_PROGRESS
-                    || call->status == call::Status::PAUSED)
+                if (call->status == call::Status::IN_PROGRESS || call->status == call::Status::PAUSED)
                     accInfo.callModel->setCurrentCall(call->id);
             } catch (...) {
             }
@@ -558,22 +541,14 @@ CallAdapter::connectCallModel(const QString& accountId)
         return;
 
     auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId);
-    connect(accInfo.callModel.get(),
-            &CallModel::callStarted,
-            this,
-            &CallAdapter::onCallStarted,
-            Qt::UniqueConnection);
+    connect(accInfo.callModel.get(), &CallModel::callStarted, this, &CallAdapter::onCallStarted, Qt::UniqueConnection);
 
-    connect(accInfo.callModel.get(),
-            &CallModel::callEnded,
-            this,
-            &CallAdapter::onCallEnded,
-            Qt::UniqueConnection);
+    connect(accInfo.callModel.get(), &CallModel::callEnded, this, &CallAdapter::onCallEnded, Qt::UniqueConnection);
 
     connect(accInfo.callModel.get(),
             &CallModel::callStatusChanged,
             this,
-            QOverload<const QString&, int>::of(&CallAdapter::onCallStatusChanged),
+            QOverload<const QString&, const QString&, int>::of(&CallAdapter::onCallStatusChanged),
             Qt::UniqueConnection);
 
     connect(accInfo.callModel.get(),
@@ -587,13 +562,18 @@ CallAdapter::connectCallModel(const QString& accountId)
             this,
             &CallAdapter::onCallAddedToConference,
             Qt::UniqueConnection);
+
+    connect(accInfo.callModel.get(),
+            &CallModel::fallbackConversationSelected,
+            this,
+            &CallAdapter::onFallbackConversationSelected,
+            Qt::UniqueConnection);
 }
 
 void
 CallAdapter::sipInputPanelPlayDTMF(const QString& key)
 {
-    auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(),
-                                                            accountId_);
+    auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (callId.isEmpty() || !lrcInstance_->getCurrentCallModel()->hasCall(callId)) {
         return;
     }
@@ -613,17 +593,16 @@ CallAdapter::saveConferenceSubcalls()
 }
 
 void
-CallAdapter::hangUpCall(const QString& callId)
+CallAdapter::endCall(const QString& callId)
 {
-    lrcInstance_->getCurrentCallModel()->hangUp(callId);
+    lrcInstance_->getCurrentCallModel()->end(callId);
 }
 
 void
 CallAdapter::setActiveStream(const QString& uri, const QString& deviceId, const QString& streamId)
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo
-        = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
 
     auto confId = convInfo.confId;
     if (confId.isEmpty())
@@ -635,8 +614,7 @@ CallAdapter::setActiveStream(const QString& uri, const QString& deviceId, const
         decltype(participants) activeParticipants = {};
         bool removeActive = false;
         for (const auto& part : participants) {
-            auto isParticipant = part.uri == uri && part.device == deviceId
-                                 && part.sinkId == streamId;
+            auto isParticipant = part.uri == uri && part.device == deviceId && part.sinkId == streamId;
             if (part.active && !isParticipant)
                 activeParticipants.push_back(part);
 
@@ -664,8 +642,7 @@ void
 CallAdapter::minimizeParticipant(const QString& uri)
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo
-        = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
     auto confId = convInfo.confId;
 
     if (confId.isEmpty())
@@ -698,8 +675,7 @@ void
 CallAdapter::showGridConferenceLayout()
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo
-        = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
 
     auto confId = convInfo.confId;
     if (confId.isEmpty())
@@ -709,16 +685,15 @@ CallAdapter::showGridConferenceLayout()
 }
 
 void
-CallAdapter::hangUpThisCall()
+CallAdapter::endCall()
 {
-    const auto& convInfo
-        = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (!convInfo.uid.isEmpty()) {
         auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
         if (!convInfo.confId.isEmpty() && callModel->hasCall(convInfo.confId)) {
-            callModel->hangUp(convInfo.confId);
+            callModel->end(convInfo.confId);
         } else if (callModel->hasCall(convInfo.callId)) {
-            callModel->hangUp(convInfo.callId);
+            callModel->end(convInfo.callId);
         }
     }
 }
@@ -726,18 +701,15 @@ CallAdapter::hangUpThisCall()
 bool
 CallAdapter::isRecordingThisCall()
 {
-    const auto& convInfo
-        = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
     auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId_);
-    return accInfo.callModel->isRecording(convInfo.confId)
-           || accInfo.callModel->isRecording(convInfo.callId);
+    return accInfo.callModel->isRecording(convInfo.confId) || accInfo.callModel->isRecording(convInfo.callId);
 }
 
 bool
 CallAdapter::isCurrentHost() const
 {
-    const auto& convInfo
-        = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (!convInfo.uid.isEmpty()) {
         auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
         try {
@@ -758,8 +730,7 @@ CallAdapter::isCurrentHost() const
 bool
 CallAdapter::participantIsHost(const QString& uri) const
 {
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
     if (!convInfo.uid.isEmpty()) {
         auto& accInfo = lrcInstance_->getAccountInfo(accountId_);
         auto* callModel = accInfo.callModel.get();
@@ -781,8 +752,7 @@ bool
 CallAdapter::isHandRaised(const QString& uri) const
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
     auto confId = convInfo.confId;
 
     if (confId.isEmpty())
@@ -794,8 +764,7 @@ void
 CallAdapter::raiseHand(const QString& uri, const QString& deviceId, bool state)
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
     auto confId = convInfo.confId;
     if (confId.isEmpty())
         confId = convInfo.callId;
@@ -809,8 +778,7 @@ void
 CallAdapter::setModerator(const QString& uri, const bool state)
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
     auto confId = convInfo.confId;
     if (confId.isEmpty())
         confId = convInfo.callId;
@@ -827,8 +795,7 @@ CallAdapter::muteParticipant(const QString& accountUri,
                              const bool state)
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
     auto confId = convInfo.confId;
 
     if (confId.isEmpty())
@@ -843,8 +810,7 @@ CallAdapter::muteParticipant(const QString& accountUri,
 CallAdapter::MuteStates
 CallAdapter::getMuteState(const QString& uri) const
 {
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
     auto confId = convInfo.confId.isEmpty() ? convInfo.callId : convInfo.confId;
     try {
@@ -874,18 +840,17 @@ CallAdapter::getMuteState(const QString& uri) const
 }
 
 void
-CallAdapter::hangupParticipant(const QString& uri, const QString& deviceId)
+CallAdapter::disconnectParticipant(const QString& uri, const QString& deviceId)
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
+    const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
     auto confId = convInfo.confId;
 
     if (confId.isEmpty())
         confId = convInfo.callId;
     try {
         const auto call = callModel->getCall(confId);
-        callModel->hangupParticipant(confId, uri, deviceId);
+        callModel->disconnectParticipant(confId, uri, deviceId);
     } catch (...) {
     }
 }
@@ -893,8 +858,7 @@ CallAdapter::hangupParticipant(const QString& uri, const QString& deviceId)
 void
 CallAdapter::holdThisCallToggle()
 {
-    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(),
-                                                                  accountId_);
+    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (callId.isEmpty() || !lrcInstance_->getCurrentCallModel()->hasCall(callId)) {
         return;
     }
@@ -924,8 +888,7 @@ CallAdapter::isMuted(const QString& callId)
 void
 CallAdapter::muteAudioToggle()
 {
-    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(),
-                                                                  accountId_);
+    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (callId.isEmpty() || !lrcInstance_->getCurrentCallModel()->hasCall(callId)) {
         return;
     }
@@ -940,8 +903,7 @@ CallAdapter::muteAudioToggle()
 void
 CallAdapter::recordThisCallToggle()
 {
-    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(),
-                                                                  accountId_);
+    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (callId.isEmpty() || !lrcInstance_->getCurrentCallModel()->hasCall(callId)) {
         return;
     }
@@ -954,8 +916,7 @@ CallAdapter::recordThisCallToggle()
 void
 CallAdapter::muteCameraToggle()
 {
-    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(),
-                                                                  accountId_);
+    const auto callId = lrcInstance_->getCallIdForConversationUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (callId.isEmpty() || !lrcInstance_->getCurrentCallModel()->hasCall(callId)) {
         return;
     }
@@ -964,10 +925,8 @@ CallAdapter::muteCameraToggle()
         const auto callInfo = lrcInstance_->getCurrentCallModel()->getCall(callId);
         auto mute = false;
         for (const auto& m : callInfo.mediaList) {
-            if (m[libjami::Media::MediaAttributeKey::SOURCE].startsWith(
-                    libjami::Media::VideoProtocolPrefix::CAMERA)
-                && m[libjami::Media::MediaAttributeKey::MEDIA_TYPE]
-                       == libjami::Media::Details::MEDIA_TYPE_VIDEO) {
+            if (m[libjami::Media::MediaAttributeKey::SOURCE].startsWith(libjami::Media::VideoProtocolPrefix::CAMERA)
+                && m[libjami::Media::MediaAttributeKey::MEDIA_TYPE] == libjami::Media::Details::MEDIA_TYPE_VIDEO) {
                 mute = m[libjami::Media::MediaAttributeKey::MUTED] == FALSE_STR;
             }
         }
@@ -996,8 +955,7 @@ CallAdapter::getCallDurationTime(const QString& accountId, const QString& convUi
         return QString();
     }
     const auto callInfo = lrcInstance_->getCurrentCallModel()->getCall(callId);
-    if (callInfo.status == lrc::api::call::Status::IN_PROGRESS
-        || callInfo.status == lrc::api::call::Status::PAUSED) {
+    if (callInfo.status == lrc::api::call::Status::IN_PROGRESS || callInfo.status == lrc::api::call::Status::PAUSED) {
         return lrcInstance_->getCurrentCallModel()->getFormattedCallDuration(callId);
     }
 
@@ -1016,8 +974,7 @@ CallAdapter::setCallInfo()
     try {
         auto& callModel = lrcInstance_->accountModel().getAccountInfo(accountId_).callModel;
         for (auto callId : callModel->getCallIds()) {
-            callInformationListModel_->addElement(
-                qMakePair(callId, callModel->advancedInformationForCallId(callId)));
+            callInformationListModel_->addElement(qMakePair(callId, callModel->advancedInformationForCallId(callId)));
         }
 
     } catch (const std::exception& e) {
