@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,23 +61,21 @@ public:
 
     Q_INVOKABLE void startTimerInformation();
     Q_INVOKABLE void stopTimerInformation();
-    Q_INVOKABLE void placeAudioOnlyCall();
-    Q_INVOKABLE void placeCall();
-    Q_INVOKABLE void hangUpACall(const QString& accountId, const QString& convUid);
+    Q_INVOKABLE void startAudioOnlyCall();
+    Q_INVOKABLE void startCall();
+    Q_INVOKABLE void endCall(const QString& accountId, const QString& convUid);
     Q_INVOKABLE void setCallMedia(const QString& accountId, const QString& convUid, bool videoMuted);
-    Q_INVOKABLE void acceptACall(const QString& accountId, const QString& convUid);
+    Q_INVOKABLE void acceptCall(const QString& accountId, const QString& convUid);
 
     Q_INVOKABLE void connectCallModel(const QString& accountId);
     Q_INVOKABLE void sipInputPanelPlayDTMF(const QString& key);
 
     // For Call Overlay
-    Q_INVOKABLE void hangUpCall(const QString& callId);
-    Q_INVOKABLE void setActiveStream(const QString& uri,
-                                     const QString& deviceId,
-                                     const QString& streamId);
+    Q_INVOKABLE void endCall(const QString& callId);
+    Q_INVOKABLE void setActiveStream(const QString& uri, const QString& deviceId, const QString& streamId);
     Q_INVOKABLE void minimizeParticipant(const QString& uri);
     Q_INVOKABLE void showGridConferenceLayout();
-    Q_INVOKABLE void hangUpThisCall();
+    Q_INVOKABLE void endCall();
     Q_INVOKABLE bool isCurrentHost() const;
     Q_INVOKABLE bool participantIsHost(const QString& uri) const;
     Q_INVOKABLE void setModerator(const QString& uri, const bool state);
@@ -96,10 +94,8 @@ public:
                                      const QString& sinkId,
                                      const bool state);
     Q_INVOKABLE MuteStates getMuteState(const QString& uri) const;
-    Q_INVOKABLE void hangupParticipant(const QString& uri, const QString& deviceId);
-    Q_INVOKABLE void updateCall(const QString& convUid = {},
-                                const QString& accountId = {},
-                                bool forceCallOnly = false);
+    Q_INVOKABLE void disconnectParticipant(const QString& uri, const QString& deviceId);
+    Q_INVOKABLE void updateCall(const QString& convUid = {}, const QString& accountId = {}, bool forceCallOnly = false);
     Q_INVOKABLE QString getCallDurationTime(const QString& accountId, const QString& convUid);
     Q_INVOKABLE void resetCallInfo();
     Q_INVOKABLE void setCallInfo();
@@ -123,6 +119,7 @@ public Q_SLOTS:
     void onCallStarted(const QString& callId);
     void onCallEnded(const QString& callId);
     void onCallInfosChanged(const QString& accountId, const QString& callId);
+    void onFallbackConversationSelected(const QString& accountId, const QString& conversationUid);
 
 private:
     void showNotification(const QString& accountId, const QString& convUid);
