@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2024-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,10 +63,7 @@ public:
     {
         TagNodeList result;
         traverseNode(
-            tidyGetRoot(doc_),
-            tags,
-            [&result](TidyNode node, TidyTagId tag) { result[tag].append(node); },
-            maxDepth);
+            tidyGetRoot(doc_), tags, [&result](TidyNode node, TidyTagId tag) { result[tag].append(node); }, maxDepth);
 
         return result;
     }
@@ -75,11 +72,7 @@ public:
     TidyNode getFirstTagNode(TidyTagId tag, int maxDepth = -1)
     {
         TidyNode result = nullptr;
-        traverseNode(
-            tidyGetRoot(doc_),
-            {tag},
-            [&result](TidyNode node, TidyTagId) { result = node; },
-            maxDepth);
+        traverseNode(tidyGetRoot(doc_), {tag}, [&result](TidyNode node, TidyTagId) { result = node; }, maxDepth);
         return result;
     }
 
