@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2015-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,8 @@ int
 main(int argc, char* argv[])
 {
     setlocale(LC_ALL, "en_US.utf8");
+    // DEBUG Uncomment this to visualize overdraw in the renderer
+    // qputenv("QSG_VISUALIZE", "overdraw");
 
 #ifdef Q_OS_LINUX
     if (!getenv("QT_QPA_PLATFORMTHEME")) {
@@ -68,8 +70,7 @@ main(int argc, char* argv[])
     QApplication::setQuitOnLastWindowClosed(false);
     QCoreApplication::setApplicationVersion(BUILD_VERSION_STRING);
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
-    QApplication::setHighDpiScaleFactorRoundingPolicy(
-        Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
+    QApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
 
 #if WITH_WEBENGINE
     qputenv("QTWEBENGINE_CHROMIUM_FLAGS",
