@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2015-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "global.h"
 #include "qmlregister.h"
 #include "appsettingsmanager.h"
+#include "accountsettingsmanager.h"
 #include "connectivitymonitor.h"
 #include "systemtray.h"
 #include "previewengine.h"
@@ -80,8 +81,7 @@ messageHandler(QtMsgType type, const QMessageLogContext& context, const QString&
     }
 #endif
 
-    const auto fmtMsg = QString("[%1][%2][%3]:%4 %5")
-                            .arg(ts, fmt[type].c_str(), tid, fileLineInfo, localMsg.constData());
+    const auto fmtMsg = QString("[%1][%2][%3]:%4 %5").arg(ts, fmt[type].c_str(), tid, fileLineInfo, localMsg.constData());
 
     (*QT_DEFAULT_MESSAGE_HANDLER)(type, context, fmtMsg);
 }
@@ -189,6 +189,7 @@ MainApplication::init()
     // enabled.
     settingsManager_ = new AppSettingsManager(this);
     crashReporter_ = new CrashReporter(settingsManager_, this);
+    accountSettingsManager_ = new AccountSettingsManager(this);
 
     // This 2-phase initialisation prevents ephemeral instances from
     // performing unnecessary tasks, like initializing the WebEngine.
@@ -254,8 +255,7 @@ MainApplication::init()
 
     auto downloadPath = settingsManager_->getValue(Settings::Key::DownloadPath);
     auto screenshotPath = settingsManager_->getValue(Settings::Key::ScreenshotPath);
-    auto allowTransferFromTrusted = settingsManager_->getValue(Settings::Key::AutoAcceptFiles)
-                                        .toBool();
+    auto allowTransferFromTrusted = settingsManager_->getValue(Settings::Key::AutoAcceptFiles).toBool();
     auto acceptTransferBelow = settingsManager_->getValue(Settings::Key::AcceptTransferBelow).toInt();
     lrcInstance_->accountModel().downloadDirectory = downloadPath.toString() + "/";
     lrcInstance_->accountModel().screenshotDirectory = screenshotPath.toString();
@@ -268,8 +268,9 @@ MainApplication::init()
 
     initQmlLayer();
 
-    settingsManager_->setValue(Settings::Key::StartMinimized,
-                               runOptions_[Option::StartMinimized].toBool());
+    accountSettingsManager_->initalizeAccountSettings();
+
+    settingsManager_->setValue(Settings::Key::StartMinimized, runOptions_[Option::StartMinimized].toBool());
 
     initSystray();
 
@@ -297,10 +298,7 @@ MainApplication::handleUriAction(const QString& arg)
 }
 
 void
-MainApplication::initLrc(const QString& downloadUrl,
-                         ConnectivityMonitor* cm,
-                         bool debugMode,
-                         bool muteDaemon)
+MainApplication::initLrc(const QString& downloadUrl, ConnectivityMonitor* cm, bool debugMode, bool muteDaemon)
 {
     lrcInstance_.reset(new LRCInstance(downloadUrl, cm, debugMode, muteDaemon));
     lrcInstance_->subscribeToDebugReceived();
@@ -319,9 +317,7 @@ MainApplication::parseArguments()
     parser_.addHelpOption();
     parser_.addVersionOption();
 
-    QCommandLineOption webDebugOption(QStringList() << "remote-debugging-port",
-                                      "Web debugging port.",
-                                      "port");
+    QCommandLineOption webDebugOption(QStringList() << "remote-debugging-port", "Web debugging port.", "port");
     parser_.addOption(webDebugOption);
 
     QCommandLineOption minimizedOption({"m", "minimized"}, "Start minimized.");
@@ -389,8 +385,7 @@ findResource(const QString& targetBasename, const QString& basePath = ":/")
 {
     QDir dir(basePath);
     // List all entries in the directory excluding special entries '.' and '..'
-    QStringList entries = dir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot,
-                                        QDir::DirsFirst);
+    QStringList entries = dir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot, QDir::DirsFirst);
 
     Q_FOREACH (const QString& entry, entries) {
         QString fullPath = basePath + "/" + entry;
@@ -402,8 +397,7 @@ findResource(const QString& targetBasename, const QString& basePath = ":/")
             if (!found.isEmpty()) {
                 return found; // Return the first match found in any subdirectory
             }
-        } else if (fileInfo.isFile()
-                   && fileInfo.fileName().contains(targetBasename, Qt::CaseInsensitive)) {
+        } else if (fileInfo.isFile() && fileInfo.fileName().contains(targetBasename, Qt::CaseInsensitive)) {
             // Match found, return the full path but remove the leading ":/".
             return fileInfo.absoluteFilePath().mid(2);
         }
@@ -421,6 +415,7 @@ MainApplication::initQmlLayer()
                          lrcInstance_.get(),
                          systemTray_,
                          settingsManager_,
+                         accountSettingsManager_,
                          connectivityMonitor_,
                          previewEngine_,
                          &screenInfo_,
@@ -484,13 +479,10 @@ MainApplication::initSystray()
     QAction* restoreAction = new QAction(tr("&Show Jami"), this);
     connect(restoreAction, &QAction::triggered, this, &MainApplication::restoreApp);
 
-    connect(systemTray_,
-            &QSystemTrayIcon::activated,
-            this,
-            [this](QSystemTrayIcon::ActivationReason reason) {
-                if (reason != QSystemTrayIcon::ActivationReason::Context) {
+    connect(systemTray_, &QSystemTrayIcon::activated, this, [this](QSystemTrayIcon::ActivationReason reason) {
+        if (reason != QSystemTrayIcon::ActivationReason::Context) {
 #ifdef Q_OS_WINDOWS
-                    restoreApp();
+            restoreApp();
 #elif !defined(Q_OS_MACOS)
                     QWindow* window = focusWindow();
                     if (window)
@@ -498,8 +490,8 @@ MainApplication::initSystray()
                     else
                         restoreApp();
 #endif
-                }
-            });
+        }
+    });
 
     menu->addAction(restoreAction);
     menu->addAction(quitAction);
