@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 class ConnectivityMonitor;
 class SystemTray;
 class AppSettingsManager;
+class AccountSettingsManager;
 class CrashReporter;
 class PreviewEngine;
 
@@ -65,14 +66,7 @@ public:
 
     Q_INVOKABLE void handleUriAction(const QString& uri = {});
 
-    enum class Option {
-        StartMinimized = 0,
-        Debug,
-        UpdateUrl,
-        MuteDaemon,
-        TerminationRequested,
-        StartUri
-    };
+    enum class Option { StartMinimized = 0, Debug, UpdateUrl, MuteDaemon, TerminationRequested, StartUri };
     QVariant getOpt(const Option opt)
     {
         return runOptions_[opt];
@@ -98,10 +92,7 @@ Q_SIGNALS:
     void searchAndSelect(const QString& request);
 
 private:
-    void initLrc(const QString& downloadUrl,
-                 ConnectivityMonitor* cm,
-                 bool debugMode,
-                 bool muteDaemon);
+    void initLrc(const QString& downloadUrl, ConnectivityMonitor* cm, bool debugMode, bool muteDaemon);
     void parseArguments();
     void setApplicationFont();
     void initQmlLayer();
@@ -118,6 +109,7 @@ private:
     ConnectivityMonitor* connectivityMonitor_;
     SystemTray* systemTray_;
     AppSettingsManager* settingsManager_;
+    AccountSettingsManager* accountSettingsManager_;
     PreviewEngine* previewEngine_;
     CrashReporter* crashReporter_;
 
