@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #include <QMimeDatabase>
 #include <QUrl>
 #include <QtMath>
-#include <QRegExp>
+#include <QRegularExpression>
 
 MessagesAdapter::MessagesAdapter(AppSettingsManager* settingsManager,
                                  PreviewEngine* previewEngine,
@@ -49,8 +49,10 @@ MessagesAdapter::MessagesAdapter(AppSettingsManager* settingsManager,
     , filteredMsgListModel_(new FilteredMsgListModel(this))
     , mediaInteractions_(std::make_unique<MessageListModel>(nullptr))
     , timestampTimer_(new QTimer(this))
+    , curLocale_(QLocale(settingsManager_->getLanguage()))
 {
     setObjectName(typeid(*this).name());
+    updateDateFormats();
 
     set_messageListModel(QVariant::fromValue(filteredMsgListModel_));
 
@@ -74,13 +76,14 @@ MessagesAdapter::MessagesAdapter(AppSettingsManager* settingsManager,
     connect(messageParser_, &MessageParser::messageParsed, this, &MessagesAdapter::onMessageParsed);
     connect(messageParser_, &MessageParser::linkInfoReady, this, &MessagesAdapter::onLinkInfoReady);
 
+    connect(settingsManager_, &AppSettingsManager::localeChanged, this, [this]() {
+        curLocale_ = QLocale((settingsManager_->getLanguage()));
+        updateDateFormats();
+    });
     connect(timestampTimer_, &QTimer::timeout, this, &MessagesAdapter::timestampUpdated);
     timestampTimer_->start(timestampUpdateIntervalMs_);
 
-    connect(lrcInstance_,
-            &LRCInstance::currentAccountIdChanged,
-            this,
-            &MessagesAdapter::connectConversationModel);
+    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, &MessagesAdapter::connectConversationModel);
 
     connectConversationModel();
 }
@@ -99,8 +102,7 @@ MessagesAdapter::loadMoreMessages()
     try {
         const auto& convInfo = lrcInstance_->getConversationFromConvUid(convId, accountId);
         if (convInfo.isSwarm())
-            lrcInstance_->getCurrentConversationModel()->loadConversationMessages(convId,
-                                                                                  loadChunkSize_);
+            lrcInstance_->getCurrentConversationModel()->loadConversationMessages(convId, loadChunkSize_);
     } catch (const std::exception& e) {
         qWarning() << e.what();
     }
@@ -185,9 +187,7 @@ MessagesAdapter::editMessage(const QString& convId, const QString& newBody, cons
 }
 
 void
-MessagesAdapter::removeEmojiReaction(const QString& convId,
-                                     const QString& emoji,
-                                     const QString& messageId)
+MessagesAdapter::removeEmojiReaction(const QString& convId, const QString& emoji, const QString& messageId)
 {
     try {
         // check if this emoji has already been added by this author
@@ -198,9 +198,7 @@ MessagesAdapter::removeEmojiReaction(const QString& convId,
 }
 
 void
-MessagesAdapter::addEmojiReaction(const QString& convId,
-                                  const QString& emoji,
-                                  const QString& messageId)
+MessagesAdapter::addEmojiReaction(const QString& convId, const QString& emoji, const QString& messageId)
 {
     try {
         lrcInstance_->getCurrentConversationModel()->reactMessage(convId, emoji, messageId);
@@ -216,10 +214,7 @@ MessagesAdapter::sendFile(const QString& message)
     QString fileName = fi.fileName();
     try {
         auto convUid = lrcInstance_->get_selectedConvUid();
-        lrcInstance_->getCurrentConversationModel()->sendFile(convUid,
-                                                              message,
-                                                              fileName,
-                                                              replyToId_);
+        lrcInstance_->getCurrentConversationModel()->sendFile(convUid, message, fileName, replyToId_);
     } catch (...) {
         qDebug() << "Exception during sendFile";
     }
@@ -231,26 +226,20 @@ MessagesAdapter::sendFileToUid(const QString& message, const QString& convUid)
     QFileInfo fi(message);
     QString fileName = fi.fileName();
     try {
-        lrcInstance_->getCurrentConversationModel()->sendFile(convUid,
-                                                              message,
-                                                              fileName,
-                                                              replyToId_);
+        lrcInstance_->getCurrentConversationModel()->sendFile(convUid, message, fileName, replyToId_);
     } catch (...) {
         qDebug() << "Exception during sendFile";
     }
 }
 
 void
-MessagesAdapter::joinCall(const QString& uri,
-                          const QString& deviceId,
-                          const QString& confId,
-                          bool isAudioOnly)
+MessagesAdapter::joinCall(const QString& uri, const QString& deviceId, const QString& confId, bool videoMuted)
 {
     lrcInstance_->getCurrentConversationModel()->joinCall(lrcInstance_->get_selectedConvUid(),
                                                           uri,
                                                           deviceId,
                                                           confId,
-                                                          isAudioOnly);
+                                                          videoMuted);
 }
 
 void
@@ -324,9 +313,8 @@ MessagesAdapter::onPaste()
         // Save temp data into a temp file.
         QPixmap pixmap = qvariant_cast<QPixmap>(mimeData->imageData());
 
-        auto img_name_hash
-            = QCryptographicHash::hash(QString::number(pixmap.cacheKey()).toLocal8Bit(),
-                                       QCryptographicHash::Sha1);
+        auto img_name_hash = QCryptographicHash::hash(QString::number(pixmap.cacheKey()).toLocal8Bit(),
+                                                      QCryptographicHash::Sha1);
         QString fileName = "img_" + QString(img_name_hash.toHex()) + ".png";
         QString path = QDir::temp().filePath(fileName);
 
@@ -377,8 +365,7 @@ MessagesAdapter::userIsComposing(bool isComposing)
 {
     if (lrcInstance_->get_selectedConvUid().isEmpty())
         return;
-    lrcInstance_->getCurrentConversationModel()->setIsComposing(lrcInstance_->get_selectedConvUid(),
-                                                                isComposing);
+    lrcInstance_->getCurrentConversationModel()->setIsComposing(lrcInstance_->get_selectedConvUid(), isComposing);
 }
 
 void
@@ -431,7 +418,7 @@ MessagesAdapter::acceptInvitation(const QString& convId)
 }
 
 void
-MessagesAdapter::refuseInvitation(const QString& convUid)
+MessagesAdapter::declineInvitation(const QString& convUid)
 {
     const auto currentConvUid = convUid.isEmpty() ? lrcInstance_->get_selectedConvUid() : convUid;
     lrcInstance_->getCurrentConversationModel()->removeConversation(currentConvUid, false);
@@ -526,19 +513,14 @@ MessagesAdapter::onConversationMessagesLoaded(uint32_t loadingRequestId, const Q
 }
 
 void
-MessagesAdapter::parseMessage(const QString& msgId,
-                              const QString& msg,
-                              bool showPreview,
-                              const QColor& linkColor,
-                              const QColor& backgroundColor)
+MessagesAdapter::parseMessage(
+    const QString& msgId, const QString& msg, bool showPreview, const QColor& linkColor, const QColor& backgroundColor)
 {
     messageParser_->parseMessage(msgId, msg, showPreview, linkColor, backgroundColor);
 }
 
 void
-MessagesAdapter::onComposingStatusChanged(const QString& convId,
-                                          const QString& contactUri,
-                                          bool isComposing)
+MessagesAdapter::onComposingStatusChanged(const QString& convId, const QString& contactUri, bool isComposing)
 {
     Q_UNUSED(contactUri)
     if (lrcInstance_->get_selectedConvUid() == convId) {
@@ -583,15 +565,13 @@ MessagesAdapter::isLocalImage(const QString& mimename)
 {
     if (mimename.startsWith("image/")) {
         QString fileFormat = mimename;
-        fileFormat.replace("image/", "");
+
         QImageReader reader;
-        QList<QByteArray> supportedFormats = reader.supportedImageFormats();
+        QList<QByteArray> supportedFormats = reader.supportedMimeTypes();
         auto iterator = std::find_if(supportedFormats.begin(),
                                      supportedFormats.end(),
-                                     [fileFormat](QByteArray format) {
-                                         return format == fileFormat;
-                                     });
-        if (iterator != supportedFormats.end() && *iterator == "gif") {
+                                     [fileFormat](const QByteArray& format) { return format == fileFormat; });
+        if (iterator != supportedFormats.end() && *iterator == "image/gif") {
             return {{"isAnimatedImage", true}};
         }
         return {{"isImage", iterator != supportedFormats.end()}};
@@ -603,20 +583,20 @@ QVariantMap
 MessagesAdapter::getMediaInfo(const QString& msg)
 {
     auto filePath = QFileInfo(msg).absoluteFilePath();
-    static const QString html
-        = "<body style='margin:0;padding:0;'>"
-          "<%1 style='width:100%;height:%2;outline:none;background-color:#f1f3f4;"
-          "object-fit:cover;' "
-          "controls controlsList='nodownload noplaybackrate' src='file://%3' type='%4'/></body>";
+    static const QString html = "<body style='margin:0;padding:0;'>"
+                                "<%1 style='width:100%;height:%2;outline:none;background-color:#f1f3f4;"
+                                "object-fit:cover;' "
+                                "controls controlsList='nodownload noplaybackrate' src='file://%3' type='%4'/></body>";
     QMimeDatabase db;
     QMimeType mime = db.mimeTypeForFile(filePath);
     QVariantMap fileInfo = isLocalImage(mime.name());
     if (fileInfo["isImage"].toBool() || fileInfo["isAnimatedImage"].toBool()) {
         return fileInfo;
     }
-    static const QRegExp vPattern("(video/)(avi|mov|webm|webp|rmvb)$", Qt::CaseInsensitive);
-    vPattern.indexIn(mime.name());
-    auto captured = vPattern.capturedTexts();
+    static const QRegularExpression vPattern("(video/)(avi|mov|webm|webp|rmvb)$",
+                                             QRegularExpression::CaseInsensitiveOption);
+    auto match = vPattern.match(mime.name());
+    auto captured = match.capturedTexts();
     QString type = captured.size() == 3 ? captured[1] : "";
     if (!type.isEmpty()) {
         return {
@@ -625,9 +605,10 @@ MessagesAdapter::getMediaInfo(const QString& msg)
             {"html", html.arg("video", "100%", filePath, mime.name())},
         };
     } else {
-        static const QRegExp aPattern("(audio/)(ogg|flac|wav|mpeg|mp3)$", Qt::CaseInsensitive);
-        aPattern.indexIn(mime.name());
-        captured = aPattern.capturedTexts();
+        static const QRegularExpression aPattern("(audio/)(ogg|flac|wav|mpeg|mp3)$",
+                                                 QRegularExpression::CaseInsensitiveOption);
+        match = aPattern.match(mime.name());
+        captured = match.capturedTexts();
         type = captured.size() == 3 ? captured[1] : "";
         if (!type.isEmpty()) {
             return {
@@ -644,9 +625,8 @@ bool
 MessagesAdapter::isRemoteImage(const QString& msg)
 {
     // TODO: test if all these open in the AnimatedImage component
-    const static QRegularExpression
-        imageRe("[^\\s]+(.*?)\\.(jpg|jpeg|png|gif|apng|webp|avif|flif)$",
-                QRegularExpression::CaseInsensitiveOption);
+    const static QRegularExpression imageRe("[^\\s]+(.*?)\\.(jpg|jpeg|png|gif|apng|webp|avif|flif)$",
+                                            QRegularExpression::CaseInsensitiveOption);
     QRegularExpressionMatch match = imageRe.match(msg);
     return match.hasMatch();
 }
@@ -656,15 +636,9 @@ MessagesAdapter::getFormattedTime(const quint64 timestamp)
 {
     const auto currentTime = QDateTime::currentDateTime();
     const auto seconds = currentTime.toSecsSinceEpoch() - timestamp;
-    auto interval = qFloor(seconds / 60);
-
-    if (interval > 1) {
-        auto curLang = settingsManager_->getLanguage();
-        auto curLocal = QLocale(curLang);
+    if (seconds > 60) {
         auto curTime = QDateTime::fromSecsSinceEpoch(timestamp).time();
-        QString timeLocale;
-        timeLocale = curLocal.toString(curTime, curLocal.ShortFormat).toLower();
-        return timeLocale;
+        return curLocale_.toString(curTime, curLocale_.ShortFormat).toLower();
     }
     return QObject::tr("Just now");
 }
@@ -679,6 +653,38 @@ MessagesAdapter::getBestFormattedDate(const quint64 timestamp)
     return getFormattedDay(timestamp);
 }
 
+void
+MessagesAdapter::updateDateFormats()
+{
+    // Derive the preferred field order from the LongFormat (e.g., "Sunday, 5 October 2025").
+    // This avoids issues with ShortFormat reflecting numeric preferences (like ISO in English)
+    // rather than the cultural text convention.
+    QString pattern = curLocale_.dateFormat(QLocale::LongFormat);
+
+    // Remove Day-Of-Week tokens to avoid counting 'd' from 'dddd' as the day of month position.
+    // We remove "dddd" first, then "ddd" to handle longest match.
+    pattern.remove("dddd");
+    pattern.remove("ddd");
+
+    int idxY = pattern.indexOf('y');
+    int idxM = pattern.indexOf('M');
+    int idxD = pattern.indexOf('d');
+
+    if (idxY != -1 && idxY < idxM && idxY < idxD) {
+        // Year first (e.g. CJK, Hungarian)
+        dateFormatCurrentYear_ = "MMM d";
+        dateFormatOtherYears_ = "yyyy MMM d";
+    } else if (idxD != -1 && idxM != -1 && idxD < idxM) {
+        // Day before Month (e.g. European, Persian)
+        dateFormatCurrentYear_ = "d MMM";
+        dateFormatOtherYears_ = "d MMM yyyy";
+    } else {
+        // Month before Day (e.g. US)
+        dateFormatCurrentYear_ = "MMM d";
+        dateFormatOtherYears_ = "MMM d, yyyy";
+    }
+}
+
 QString
 MessagesAdapter::getFormattedDay(const quint64 timestamp)
 {
@@ -686,16 +692,17 @@ MessagesAdapter::getFormattedDay(const quint64 timestamp)
     auto timestampDate = QDateTime::fromSecsSinceEpoch(timestamp).date();
     if (timestampDate == currentDate)
         return QObject::tr("Today");
-    if (timestampDate.daysTo(currentDate) == 1)
+
+    auto daysDiff = timestampDate.daysTo(currentDate);
+    if (daysDiff == 1)
         return QObject::tr("Yesterday");
 
-    auto curLang = settingsManager_->getLanguage();
-    auto curLocal = QLocale(curLang);
-    auto curDate = QDateTime::fromSecsSinceEpoch(timestamp).date();
-    QString dateLocale;
-    dateLocale = curLocal.toString(curDate, curLocal.ShortFormat);
+    if (daysDiff < 7 && daysDiff > 0)
+        return curLocale_.dayName(timestampDate.dayOfWeek());
 
-    return dateLocale;
+    if (timestampDate.year() == currentDate.year())
+        return curLocale_.toString(timestampDate, dateFormatCurrentYear_);
+    return curLocale_.toString(timestampDate, dateFormatOtherYears_);
 }
 
 void
@@ -711,10 +718,7 @@ MessagesAdapter::startSearch(const QString& text, bool isMedia)
     auto convId = lrcInstance_->get_selectedConvUid();
 
     try {
-        lrcInstance_->getCurrentConversationModel()->getConvMediasInfos(accountId,
-                                                                        convId,
-                                                                        text,
-                                                                        isMedia);
+        lrcInstance_->getCurrentConversationModel()->getConvMediasInfos(accountId, convId, text, isMedia);
     } catch (...) {
         qDebug() << "Exception during startSearch()";
     }
