@@ -1,5 +1,5 @@
 /*!
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,9 +46,7 @@ public:
                                  qApp->property("AppSettingsManager").value<AppSettingsManager*>());
     }
 
-    explicit PluginAdapter(LRCInstance* instance,
-                           AppSettingsManager* settingsManager,
-                           QObject* parent = nullptr);
+    explicit PluginAdapter(LRCInstance* instance, AppSettingsManager* settingsManager, QObject* parent = nullptr);
     ~PluginAdapter() = default;
 
     Q_INVOKABLE void getPluginsFromStore();
@@ -64,8 +62,7 @@ public:
 
 protected:
     Q_INVOKABLE QVariant getMediaHandlerSelectableModel(const QString& callId);
-    Q_INVOKABLE QVariant getChatHandlerSelectableModel(const QString& accountId,
-                                                       const QString& peerId);
+    Q_INVOKABLE QVariant getChatHandlerSelectableModel(const QString& accountId, const QString& peerId);
     Q_INVOKABLE QVariant getPluginPreferencesCategories(const QString& pluginId,
                                                         const QString& accountId,
                                                         bool removeLast = false);
