@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2021-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,8 +72,7 @@ PreviewEngine::~PreviewEngine()
 void
 PreviewEngine::onParseLink(const QString& id, const QString& link)
 {
-    sendGetRequest(link,
-                   [this, id, link](const QByteArray& html) { Q_EMIT htmlReady(id, link, html); });
+    sendGetRequest(link, [this, id, link](const QByteArray& html) { Q_EMIT htmlReady(id, link, html); });
 }
 
 PreviewEngine::Parser::Parser(QObject* parent)
@@ -85,8 +84,7 @@ QString
 PreviewEngine::Parser::getTagContent(const QList<QString>& tags, const QString& value)
 {
     Q_FOREACH (auto tag, tags) {
-        const QRegularExpression re("(property|name)=\"(og:|twitter:|)" + value
-                                    + "\".*?content=\"([^\"]+)\"");
+        const QRegularExpression re("(property|name)=\"(og:|twitter:|)" + value + "\".*?content=\"([^\"]+)\"");
         const auto match = re.match(tag.remove(newlineRe));
         if (match.hasMatch()) {
             return match.captured(3);
