@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@
 #include "mediacodeclistmodel.h"
 #include "audiodevicemodel.h"
 #include "audiomanagerlistmodel.h"
+#include "audioconfiglistmodel.h"
 #include "bannedlistmodel.h"
 #include "moderatorlistmodel.h"
 #include "deviceitemlistmodel.h"
@@ -57,6 +58,7 @@
 #include "avatarimageprovider.h"
 #include "avatarregistry.h"
 #include "appsettingsmanager.h"
+#include "accountsettingsmanager.h"
 #include "mainapplication.h"
 #include "namedirectory.h"
 #include "pluginversionmanager.h"
@@ -119,6 +121,7 @@ registerTypes(QQmlEngine* engine,
               LRCInstance* lrcInstance,
               SystemTray* systemTray,
               AppSettingsManager* settingsManager,
+              AccountSettingsManager* accountSettingsManager,
               ConnectivityMonitor* connectivityMonitor,
               PreviewEngine* previewEngine,
               ScreenInfo* screenInfo,
@@ -205,6 +208,7 @@ registerTypes(QQmlEngine* engine,
     qApp->setProperty("LRCInstance", QVariant::fromValue(lrcInstance));
     qApp->setProperty("SystemTray", QVariant::fromValue(systemTray));
     qApp->setProperty("AppSettingsManager", QVariant::fromValue(settingsManager));
+    qApp->setProperty("AccountSettingsManager", QVariant::fromValue(accountSettingsManager));
     qApp->setProperty("ConnectivityMonitor", QVariant::fromValue(connectivityMonitor));
     qApp->setProperty("PreviewEngine", QVariant::fromValue(previewEngine));
 
@@ -240,6 +244,7 @@ registerTypes(QQmlEngine* engine,
     QML_REGISTERTYPE(NS_MODELS, MediaCodecListModel);
     QML_REGISTERTYPE(NS_MODELS, AudioDeviceModel);
     QML_REGISTERTYPE(NS_MODELS, AudioManagerListModel);
+    QML_REGISTERTYPE(NS_MODELS, AudioConfigListModel);
     QML_REGISTERTYPE(NS_MODELS, PreferenceItemListModel);
     QML_REGISTERTYPE(NS_MODELS, PluginListPreferenceModel);
     QML_REGISTERTYPE(NS_MODELS, FilesToSendListModel);
@@ -258,6 +263,7 @@ registerTypes(QQmlEngine* engine,
     QML_REGISTERSINGLETONTYPE_POBJECT(NS_CONSTANTS, screenInfo, "CurrentScreenInfo")
     QML_REGISTERSINGLETONTYPE_POBJECT(NS_CONSTANTS, lrcInstance, "LRCInstance")
     QML_REGISTERSINGLETONTYPE_POBJECT(NS_CONSTANTS, settingsManager, "AppSettingsManager")
+    QML_REGISTERSINGLETONTYPE_POBJECT(NS_CONSTANTS, accountSettingsManager, "AccountSettingsManager")
 
     // Lrc namespaces, models, and singletons
     QML_REGISTERNAMESPACE(NS_MODELS, lrc::api::staticMetaObject, "Lrc");
