@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 class SystemTray;
 class LRCInstance;
 class AppSettingsManager;
+class AccountSettingsManager;
 class PreviewEngine;
 class ScreenInfo;
 class MainApplication;
@@ -61,6 +62,7 @@ void registerTypes(QQmlEngine* engine,
                    LRCInstance* lrcInstance,
                    SystemTray* systemTray,
                    AppSettingsManager* appSettingsManager,
+                   AccountSettingsManager* accountSettingsManager,
                    ConnectivityMonitor* connectivityMonitor,
                    PreviewEngine* previewEngine,
                    ScreenInfo* screenInfo,
