@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2021-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -150,8 +150,7 @@ SelectableListProxyModel::onModelTrimmed()
     updateSelection(true);
 }
 
-SelectableListProxyGroupModel::SelectableListProxyGroupModel(QList<SelectableListProxyModel*> models,
-                                                             QObject* parent)
+SelectableListProxyGroupModel::SelectableListProxyGroupModel(QList<SelectableListProxyModel*> models, QObject* parent)
     : QObject(parent)
     , models_(models)
 {
