@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2015-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,9 +29,10 @@
 #include <QBuffer>
 #include <QClipboard>
 #include <QFileInfo>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QMimeData>
 #include <QMimeDatabase>
+#include <QStyleHints>
 
 UtilsAdapter::UtilsAdapter(AppSettingsManager* settingsManager,
                            SystemTray* systemTray,
@@ -83,8 +84,6 @@ UtilsAdapter::setAppValue(const Settings::Key key, const QVariant& value)
         Q_EMIT changeFontSize();
     else if (key == Settings::Key::DisplayHyperlinkPreviews)
         settingsManager_->loadHistory();
-    else if (key == Settings::Key::EnableExperimentalSwarm)
-        Q_EMIT showExperimentalCallSwarm();
     else if (key == Settings::Key::ShowChatviewHorizontally)
         Q_EMIT chatviewPositionChanged();
     else if (key == Settings::Key::AppTheme)
@@ -99,8 +98,7 @@ UtilsAdapter::setAppValue(const Settings::Key key, const QVariant& value)
         Q_EMIT raiseWhenCalledChanged();
 #if !APPSTORE
     // Any donation campaign-related keys can trigger a donation campaign check
-    else if (key == Settings::Key::IsDonationVisible
-             || key == Settings::Key::Donation2025StartDate
+    else if (key == Settings::Key::IsDonationVisible || key == Settings::Key::Donation2025StartDate
              || key == Settings::Key::Donation2025EndDate)
         Q_EMIT donationCampaignSettingsChanged();
 #endif
@@ -178,8 +176,7 @@ UtilsAdapter::getCachePath()
 QString
 UtilsAdapter::getDefaultRecordPath() const
 {
-    auto defaultDirectory = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)
-                            + "/Jami";
+    auto defaultDirectory = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + "/Jami";
     QDir dir(defaultDirectory);
     if (!dir.exists())
         dir.mkpath(".");
@@ -209,8 +206,7 @@ UtilsAdapter::getBestName(const QString& accountId, const QString& uid)
 {
     const auto& conv = lrcInstance_->getConversationFromConvUid(uid);
     if (!conv.participants.isEmpty())
-        return lrcInstance_->getAccountInfo(accountId).contactModel->bestNameForContact(
-            conv.participants[0].uri);
+        return lrcInstance_->getAccountInfo(accountId).contactModel->bestNameForContact(conv.participants[0].uri);
     return QString();
 }
 
@@ -267,8 +263,7 @@ UtilsAdapter::getBestId(const QString& accountId, const QString& uid)
 {
     const auto& conv = lrcInstance_->getConversationFromConvUid(uid);
     if (!conv.participants.isEmpty())
-        return lrcInstance_->getAccountInfo(accountId).contactModel->bestIdForContact(
-            conv.participants[0].uri);
+        return lrcInstance_->getAccountInfo(accountId).contactModel->bestIdForContact(conv.participants[0].uri);
     return QString();
 }
 
@@ -387,7 +382,7 @@ UtilsAdapter::toFileAbsolutepath(QString inputFileName)
 QString
 UtilsAdapter::getAbsPath(QString path)
 {
-    static auto fileSchemeRe = QRegularExpression("^file:\\/{2,3}");
+    static const auto fileSchemeRe = QRegularExpression("^file:\\/{2,3}");
     // Note: this function is used on urls returned from qml-FileDialogs which
     // contain 'file:///' for reasons we don't understand.
     // TODO: this logic can be refactored into the JamiFileDialog component.
@@ -440,8 +435,7 @@ UtilsAdapter::setSystemTrayIconVisible(bool visible)
 QString
 UtilsAdapter::getDirDocument()
 {
-    return QDir::toNativeSeparators(
-        QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
+    return QDir::toNativeSeparators(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
 }
 
 QString
@@ -514,17 +508,16 @@ UtilsAdapter::monitor(const bool& continuous)
 {
     disconnect(debugMessageReceivedConnection_);
     if (continuous)
-        debugMessageReceivedConnection_
-            = QObject::connect(&lrcInstance_->behaviorController(),
-                               &lrc::api::BehaviorController::debugMessageReceived,
-                               this,
-                               [this](const QString& data) {
-                                   logList_.append(data);
-                                   if (logList_.size() >= LOGSLIMIT) {
-                                       logList_.removeFirst();
-                                   }
-                                   Q_EMIT debugMessageReceived(data);
-                               });
+        debugMessageReceivedConnection_ = QObject::connect(&lrcInstance_->behaviorController(),
+                                                           &lrc::api::BehaviorController::debugMessageReceived,
+                                                           this,
+                                                           [this](const QString& data) {
+                                                               logList_.append(data);
+                                                               if (logList_.size() >= LOGSLIMIT) {
+                                                                   logList_.removeFirst();
+                                                               }
+                                                               Q_EMIT debugMessageReceived(data);
+                                                           });
     lrcInstance_->monitor(continuous);
 }
 
@@ -545,11 +538,11 @@ UtilsAdapter::supportedLang()
     QVariantMap result;
     result["SYSTEM"] = tr("System");
     // Get available locales
-    QRegExp regex("jami_client_qt_(.*).qm");
+    static const QRegularExpression regex("jami_client_qt_(.*).qm");
     QSet<QString> nativeNames;
     for (const auto& f : trFiles) {
-        regex.indexIn(f);
-        auto captured = regex.capturedTexts();
+        auto match = regex.match(f);
+        auto captured = match.capturedTexts();
         if (captured.size() == 2) {
             auto nativeName = QLocale(captured[1]).nativeLanguageName();
             if (nativeName.isEmpty()) // If a locale doesn't have any nativeLanguageName, ignore it.
@@ -609,9 +602,7 @@ UtilsAdapter::setTempCreationImageFromImage(const QImage& image, const QString&
         file.close();
         Q_EMIT lrcInstance_->base64SwarmAvatarChanged();
     } else {
-        lrcInstance_->getCurrentConversationModel()->updateConversationInfos(imageId,
-                                                                             {{"avatar",
-                                                                               ba.toBase64()}});
+        lrcInstance_->getCurrentConversationModel()->updateConversationInfos(imageId, {{"avatar", ba.toBase64()}});
     }
 }
 
@@ -633,8 +624,7 @@ UtilsAdapter::getContactBestName(const QString& accountId, const QString& uri)
 {
     try {
         if (lrcInstance_->getAccountInfo(accountId).profileInfo.uri == uri)
-            return lrcInstance_->accountModel().bestNameForAccount(
-                accountId); // It's the same account
+            return lrcInstance_->accountModel().bestNameForAccount(accountId); // It's the same account
         return lrcInstance_->getAccountInfo(accountId).contactModel->bestNameForContact(uri);
     } catch (...) {
     }
@@ -654,8 +644,7 @@ UtilsAdapter::getParticipantRole(const QString& accountId, const QString& convId
 bool
 UtilsAdapter::luma(const QColor& color) const
 {
-    return (0.2126 * color.red() + 0.7152 * color.green() + 0.0722 * color.blue())
-           < 153 /* .6 * 256 */;
+    return (0.2126 * color.red() + 0.7152 * color.green() + 0.0722 * color.blue()) < 153 /* .6 * 256 */;
 }
 
 #if __has_include(<gio/gio.h>)
@@ -675,12 +664,11 @@ readAppsUseLightThemeRegistry(bool getValue)
 {
     auto returnValue = true;
     HKEY hKey;
-    auto lResult
-        = RegOpenKeyEx(HKEY_CURRENT_USER,
-                       TEXT("Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize"),
-                       0,
-                       KEY_READ,
-                       &hKey);
+    auto lResult = RegOpenKeyEx(HKEY_CURRENT_USER,
+                                TEXT("Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize"),
+                                0,
+                                KEY_READ,
+                                &hKey);
 
     if (lResult != ERROR_SUCCESS) {
         RegCloseKey(hKey);
@@ -735,15 +723,13 @@ UtilsAdapter::isSystemThemeDark()
             if (auto* valueCstr = g_settings_get_string(settings, key.c_str())) {
                 QString value = valueCstr;
                 if (!value.isEmpty()) {
-                    return value.contains("dark", Qt::CaseInsensitive)
-                           || value.contains("black", Qt::CaseInsensitive);
+                    return value.contains("dark", Qt::CaseInsensitive) || value.contains("black", Qt::CaseInsensitive);
                 }
             }
         }
     }
     return false;
-#else
-#if defined(WIN32) && __has_include(<winrt/Windows.Foundation.h>)
+#elif defined(WIN32) && __has_include(<winrt/Windows.Foundation.h>)
 #if WATCHSYSTEMTHEME
     if (!settings) {
         settings = UISettings();
@@ -751,10 +737,12 @@ UtilsAdapter::isSystemThemeDark()
     }
 #endif
     return readAppsUseLightThemeRegistry(true);
+#elif defined(Q_OS_MACOS) || defined(Q_OS_MAC)
+    QObject::connect(qApp->styleHints(), &QStyleHints::colorSchemeChanged, this, [this]() { Q_EMIT appThemeChanged(); });
+    return qApp->styleHints()->colorScheme() == Qt::ColorScheme::Dark;
 #else
     C_WARN << "System theme detection is not implemented or is not supported";
     return false;
-#endif // WIN32
 #endif // __has_include(<gio/gio.h>)
 }
 
@@ -774,13 +762,13 @@ UtilsAdapter::hasNativeDarkTheme() const
 {
 #if __has_include(<gio/gio.h>)
     return true;
-#else
-#if defined(WIN32) && __has_include(<winrt/Windows.Foundation.h>)
+#elif defined(WIN32) && __has_include(<winrt/Windows.Foundation.h>)
     return readAppsUseLightThemeRegistry(false);
+#elif defined(Q_OS_MACOS) || defined(Q_OS_MAC)
+    return true;
 #else
     return false;
 #endif
-#endif
 }
 
 QString
@@ -796,12 +784,11 @@ UtilsAdapter::getOneline(const QString& input)
 QVariantMap
 UtilsAdapter::getVideoPlayer(const QString& resource, const QString& bgColor)
 {
-    static const QString htmlVideo
-        = "<body style='margin:0;padding:0;'>"
-          "<video autoplay muted loop "
-          "style='width:100%;height:100%;outline:none;background-color:%2;"
-          "object-fit:cover;' "
-          "src='%1' type='video/webm'/></body>";
+    static const QString htmlVideo = "<body style='margin:0;padding:0;'>"
+                                     "<video autoplay muted loop "
+                                     "style='width:100%;height:100%;outline:none;background-color:%2;"
+                                     "object-fit:cover;' "
+                                     "src='%1' type='video/webm'/></body>";
     return {
         {"isVideo", true},
         {"html", htmlVideo.arg(resource, bgColor)},
@@ -855,8 +842,7 @@ UtilsAdapter::fileExists(const QString& filePath)
 QString
 UtilsAdapter::getStandardTempLocation()
 {
-    return QStandardPaths::writableLocation(
-        static_cast<QStandardPaths::StandardLocation>(QStandardPaths::TempLocation));
+    return QStandardPaths::writableLocation(static_cast<QStandardPaths::StandardLocation>(QStandardPaths::TempLocation));
 }
 
 QString
