@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2015-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -138,12 +138,9 @@ public:
     Q_INVOKABLE void monitor(const bool& continuous);
     Q_INVOKABLE QVariantMap supportedLang();
     Q_INVOKABLE QString tempCreationImage(const QString& imageId = "temp") const;
-    Q_INVOKABLE void setTempCreationImageFromString(const QString& image = "",
-                                                    const QString& imageId = "temp");
-    Q_INVOKABLE void setTempCreationImageFromFile(const QString& path,
-                                                  const QString& imageId = "temp");
-    Q_INVOKABLE void setTempCreationImageFromImage(const QImage& image,
-                                                   const QString& imageId = "temp");
+    Q_INVOKABLE void setTempCreationImageFromString(const QString& image = "", const QString& imageId = "temp");
+    Q_INVOKABLE void setTempCreationImageFromFile(const QString& path, const QString& imageId = "temp");
+    Q_INVOKABLE void setTempCreationImageFromImage(const QImage& image, const QString& imageId = "temp");
 
     // For Swarm details page
     Q_INVOKABLE int getContactPresence(const QString& accountId, const QString& uri);
@@ -177,7 +174,6 @@ Q_SIGNALS:
     void changeFontSize();
     void chatviewPositionChanged();
     void appThemeChanged();
-    void showExperimentalCallSwarm();
     void changeLanguage();
     void donationCampaignSettingsChanged();
     void useFramelessWindowChanged();
