@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2018-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2018-2026 Savoir-faire Linux Inc.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -122,6 +122,21 @@ public:
      * @return audio outputs
      */
     QVector<QString> getAudioOutputDevices() const;
+    /**
+     * Get the current config option for noise reduction
+     * @return The noise suppression option
+     */
+    Q_INVOKABLE QString getNoiseSuppression() const;
+    /**
+     * Get the current config option for echo cancellation
+     * @return The echo cancellation option
+     */
+    Q_INVOKABLE QString getEchoCancellation() const;
+    /**
+     * Get the current config option for voice activity detection
+     * @return The voice activity detection option
+     */
+    Q_INVOKABLE bool getVoiceActivityDetection() const;
     /**
      * Get current audio inputs
      * @return audio inputs
@@ -166,6 +181,21 @@ public:
      * @return if the operation is successful
      */
     Q_INVOKABLE bool setAudioManager(const QString& name);
+    /**
+     * Set the current noise reduction option
+     * @param name of the new noise reduction option
+     */
+    Q_INVOKABLE void setNoiseSuppression(const QString& name);
+    /**
+     * Set the current echo cancellation option
+     * @param name of the new echo cancellation option
+     */
+    Q_INVOKABLE void setEchoCancellation(const QString& name);
+    /**
+     * Set the current voice activity detection option
+     * @param state of the new voice activity detection option
+     */
+    Q_INVOKABLE void setVoiceActivityDetection(bool state);
     /**
      * Set current ringtone device
      * @param idx of the new ringtone device
