@@ -1,5 +1,5 @@
 /****************************************************************************
- *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
+ *   Copyright (C) 2017-2026 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -173,8 +173,8 @@ struct Info
                         previewId = media[MediaAttributeKey::SOURCE];
                     }
                 }
-                if (media[MediaAttributeKey::ENABLED] == TRUE_STR
-                    && media[MediaAttributeKey::MUTED] == FALSE_STR && previewId.isEmpty()) {
+                if (media[MediaAttributeKey::ENABLED] == TRUE_STR && media[MediaAttributeKey::MUTED] == FALSE_STR
+                    && previewId.isEmpty()) {
                     previewId = media[libjami::Media::MediaAttributeKey::SOURCE];
                 }
                 if (media[libjami::Media::MediaAttributeKey::SOURCE].startsWith(
