@@ -1,19 +1,20 @@
-/****************************************************************************
- *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
- *                                                                          *
- *   This library is free software; you can redistribute it and/or          *
- *   modify it under the terms of the GNU Lesser General Public             *
- *   License as published by the Free Software Foundation; either           *
- *   version 2.1 of the License, or (at your option) any later version.     *
- *                                                                          *
- *   This library is distributed in the hope that it will be useful,        *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
- *   Lesser General Public License for more details.                        *
- *                                                                          *
- *   You should have received a copy of the GNU General Public License      *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
- ***************************************************************************/
+/*
+ * Copyright (C) 2017-2026 Savoir-faire Linux Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #pragma once
 
 #include "api/behaviorcontroller.h"
@@ -26,12 +27,14 @@
 
 #include <memory>
 #include <map>
+#include <optional>
 
 namespace lrc {
 
 class CallbacksHandler;
 class CallModelPimpl;
 
+void initializeMediaList(VectorMapStringString& mediaList, bool audioOnly, bool videoMuted);
 namespace api {
 
 namespace account {
@@ -80,7 +83,8 @@ public:
      */
     QString createCall(const QString& uri,
                        bool isAudioOnly = false,
-                       VectorMapStringString mediaList = {});
+                       VectorMapStringString mediaList = {},
+                       bool videoMuted = true);
     /**
      * Add a new media to the current list
      * @param callId
@@ -125,11 +129,8 @@ public:
      * @param mute
      * @param removeAll     Remove Audio/Video
      */
-    void removeMedia(const QString& callId,
-                     const QString& mediaType,
-                     const QString& type,
-                     bool muteCamera,
-                     bool removeAll);
+    void removeMedia(
+        const QString& callId, const QString& mediaType, const QString& type, bool muteCamera, bool removeAll);
 
     /**
      * Get the call from its call id
@@ -148,7 +149,7 @@ public:
     const CallParticipants& getParticipantsInfos(const QString& callId);
 
     /**
-     * Get the call from the peer uri
+     * Get the call from the peer URI
      * @param  uri
      * @param  notOver search for a non finished call
      * @return the callInfo
@@ -183,22 +184,22 @@ public:
     void sendSipMessage(const QString& callId, const QString& body) const;
 
     /**
-     * Accept a call
+     * Accept call
      * @param callId
      */
     void accept(const QString& callId) const;
 
     /**
-     * Hang up a call
+     * End call
      * @param callId
      */
-    void hangUp(const QString& callId) const;
+    void end(const QString& callId) const;
 
     /**
-     * Refuse a call
+     * Decline call
      * @param callId
      */
-    void refuse(const QString& callId) const;
+    void decline(const QString& callId) const;
 
     /**
      * Toggle audio record on a call
@@ -305,11 +306,8 @@ public:
      * @param sinkId        Peer's sinkId
      * @param state         new state wanted
      */
-    void setActiveStream(const QString& confId,
-                         const QString& accountUri,
-                         const QString& deviceId,
-                         const QString& sinkId,
-                         bool state);
+    void setActiveStream(
+        const QString& confId, const QString& accountUri, const QString& deviceId, const QString& sinkId, bool state);
 
     /**
      * Check if a participant is a moderator or not
@@ -342,10 +340,7 @@ public:
      * @param deviceId      DeviceId of the participant to change
      * @param state         State of the change (true set hand raised / false unset hand raised)
      */
-    void raiseHand(const QString& confId,
-                   const QString& accountUri,
-                   const QString& deviceId,
-                   bool state);
+    void raiseHand(const QString& confId, const QString& accountUri, const QString& deviceId, bool state);
 
     /**
      * Mute/unmute sink
@@ -362,14 +357,12 @@ public:
                     const bool& state);
 
     /**
-     * Hangup participant from the conference
+     * Disconnect participant from the conference
      * @param confId        The call to change
-     * @param accountUri    Uri of the participant to mute
-     * @param deviceId      Device Id of the participant to mute
+     * @param accountUri    URI of the participant to mute
+     * @param deviceId      Device ID of the participant to mute
      */
-    void hangupParticipant(const QString& confId,
-                           const QString& accountUri,
-                           const QString& deviceId);
+    void disconnectParticipant(const QString& confId, const QString& accountUri, const QString& deviceId);
 
     /**
      * Check if a call is a conference or not
@@ -406,9 +399,7 @@ public:
      * @param windowProcessId
      * @param windowId
      */
-    QString getDisplay(const QString& windowProcessId,
-                       const QString& windowId,
-                       const int fps = -1);
+    QString getDisplay(const QString& windowProcessId, const QString& windowId, const int fps = -1);
 
     void emplaceConversationConference(const QString& callId);
 
@@ -483,9 +474,7 @@ Q_SIGNALS:
      * @param conversationId
      * @param confId
      */
-    void callAddedToConference(const QString& callId,
-                               const QString& conversationId,
-                               const QString& confId) const;
+    void callAddedToConference(const QString& callId, const QString& conversationId, const QString& confId) const;
 
     /**
      * Emitted when a voice mail notice arrives
@@ -494,10 +483,7 @@ Q_SIGNALS:
      * @param oldCount
      * @param urgentCount
      */
-    void voiceMailNotify(const QString& accountId,
-                         int newCount,
-                         int oldCount,
-                         int urgentCount) const;
+    void voiceMailNotify(const QString& accountId, int newCount, int oldCount, int urgentCount) const;
 
     /**
      * Provides notification of a new set of recording peers once a change has occured,
@@ -544,9 +530,29 @@ Q_SIGNALS:
      */
     void currentCallChanged(const QString& callId) const;
 
+    /**
+     * Emitted when the call is transferred to a fallback conversation
+     * due to conference participant changes (e.g., one participant leaves)
+     * @param accountId The account owning the conversation
+     * @param conversationUid The UID of the conversation to switch to
+     */
+    void fallbackConversationSelected(const QString& accountId, const QString& conversationUid) const;
+
+    /**
+     * Decision helper to pick a fallback conversation UID.
+     * Exposed for unit tests.
+     */
+#ifndef Q_MOC_RUN
+    static std::optional<QString> computeFallbackConversation(bool currentIsCoreDialog,
+                                                              const QString& currentConversationUid,
+                                                              const QStringList& remoteParticipantUris,
+                                                              const QMap<QString, QString>& peerUriToConversationUid);
+#endif
+
 private:
     std::unique_ptr<CallModelPimpl> pimpl_;
 };
 } // namespace api
 } // namespace lrc
+
 Q_DECLARE_METATYPE(lrc::api::CallModel*)
