@@ -1,19 +1,20 @@
-/****************************************************************************
- *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
- *                                                                          *
- *   This library is free software; you can redistribute it and/or          *
- *   modify it under the terms of the GNU Lesser General Public             *
- *   License as published by the Free Software Foundation; either           *
- *   version 2.1 of the License, or (at your option) any later version.     *
- *                                                                          *
- *   This library is distributed in the hope that it will be useful,        *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
- *   Lesser General Public License for more details.                        *
- *                                                                          *
- *   You should have received a copy of the GNU General Public License      *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
- ***************************************************************************/
+/*
+ * Copyright (C) 2017-2026 Savoir-faire Linux Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "api/lrc.h"
 
 #if !defined(_MSC_VER)
@@ -160,17 +161,17 @@ Lrc::activeCalls(const QString& accountId)
 }
 
 void
-Lrc::hangupCallsAndConferences()
+Lrc::endCallsAndConferences()
 {
     const QStringList accountIds = ConfigurationManager::instance().getAccountList();
     for (const auto& accId : accountIds) {
         QStringList conferences = CallManager::instance().getConferenceList(accId);
         for (const auto& conf : conferences) {
-            CallManager::instance().hangUpConference(accId, conf);
+            CallManager::instance().endConference(accId, conf);
         }
         QStringList calls = CallManager::instance().getCallList(accId);
         for (const auto& call : calls) {
-            CallManager::instance().hangUp(accId, call);
+            CallManager::instance().end(accId, call);
         }
     }
 }
